#
# Unit tests for class FindMin
#

import unittest
from find_min.find_min import FindMin
from find_min.sample.sample_file import SampleFile 


class FindMinTests(unittest.TestCase):


    def run_all(self):
        sf = SampleFile()
        samples = sf.load('..\samples.json')


    def test_equal(self, samples):
        fm = FindMin()

        for sample in samples.values():
            result = fm.findMin(sample["sample"])
            self.assertEqual(result, sample["output"])
            print("✓ Test passed for sample {0}".format(sample["sample"]))


if __name__ == '__main__':
    unittest.main()


#
# A class to load samples from JSON file
#

import json
import os


class SampleFile:

    @property
    def file_path(self): 
        dirname = os.path.dirname(__file__)
        path = os.path.join(dirname, '.\samples.py')
        return path 


    def load(self):
        return self.loadFile(self.file_path)


    def loadFile(self, path):
        with open(path) as jsonfile:
            samples = json.load(jsonfile)

        return samples



#
# The core class to find min in an array
#
from find_min.sample.sample_file import SampleFile 


class FindMin:


    def printSample(self):
        sf = SampleFile()
        samples = sf.load()

        fm = FindMin()
        fm.printMin(samples)


    def findMin(self, nums):
        i = 1
        size = len(nums)
        minimum = None
        
        if (size == 1):
            return nums[0]
        
        while i < size:
            minimum = nums[i]
            if (nums[i-1] < minimum):
                minimum = nums[i-1]
                break

            i += 1
        
        return minimum


    def printMin(self, samples):
        for sample in samples.values():
            min = self.findMin(sample["sample"])
            print("Min is ({0}) in {1}".format(min, sample["sample"]))





import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="findMin",
    version="7.0.0",
    author="Syed Rafey Husain",
    author_email="rafey.husain@outlook.com",
    description="Find the minimum in array using as few comparisons as possible",
    long_description="Given an array of elements that provide a less than operator, find the minimum using as few comparisons as possible. The array shall be given such that the first few elements are strictly monotonically decreasing, the remaining elements are strictly monotonically increasing. The less than operator be defined as the operator that works on such arrays where a < b if min(a,b) == a.",
    long_description_content_type="text/markdown",
    url="https://github.com/rafey.husain/findMin",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)